@@ -133,7 +133,7 @@ void MntConfigWidget::applySettings( void )
 {
     mDiskList.applySettings();
 
-    KConfigGroup config(KSharedConfig::openConfig(), "MntConfig");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("MntConfig"));
     if( GUI )
     {
         config.writeEntry("Width", width() );
@@ -145,14 +145,10 @@ void MntConfigWidget::applySettings( void )
 
 void MntConfigWidget::loadSettings( void )
 {
-    KConfigGroup config = KSharedConfig::openConfig()->group("MntConfig");
+    KConfigGroup config = KSharedConfig::openConfig()->group(QStringLiteral("MntConfig"));
     if( !mInitializing && GUI )
     {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        if( isTopLevel() )
-#else
         if( isWindow() )
-#endif
         {
             int w = config.readEntry("Width",this->width() );
             int h = config.readEntry("Height",this->height() );
@@ -325,3 +321,5 @@ void MntConfigWidget::slotChanged()
 }
 
 
+
+#include "moc_mntconfig.cpp"
